@@ -18,7 +18,7 @@ def month_ru(month):
     months = ["январь", "февраль", "март", "апрель", "май", "июнь", "июль", "август", "сентябрь", "октябрь", "ноябрь", "декабрь"]
     return months[int(month)-1]
 
-def plural_date_ru(dt, year=False):
+def hum_month_ru(dt, year=False):
     months = ["января", "февраля", "марта", "апреля", "мая", "июня", "июля", "августа", "сентября", "октября", "ноября", "декабря"]
     result = "%d %s"%(dt.day, months[dt.month-1])
     if year:
